@@ -148,7 +148,7 @@ class set:
                 with open("user.txt","w",encoding="utf-8") as file:
                     file.write("")
                 update.message.reply_text("Bütün Kullanıcılar Silindi")
-        def photo(update,context):
+        def takephoto(update,context):
             if login(update,context):
                 print("Kameraya giriş yapıldı")
                 try:
@@ -173,7 +173,7 @@ class set:
         updater.dispatcher.add_handler(CommandHandler('pindelete', pin_delete))
         updater.dispatcher.add_handler(CommandHandler('userdelete', user_delete))
         updater.dispatcher.add_handler(CommandHandler('restart', restart))
-        updater.dispatcher.add_handler(CommandHandler('photo', photo))
+        updater.dispatcher.add_handler(CommandHandler('takephoto', takephoto))
         updater.dispatcher.add_handler(CallbackQueryHandler(button))
         updater.dispatcher.add_handler(CommandHandler('help', help_command))
         updater.dispatcher.add_handler(MessageHandler(Filters.text & ~Filters.command, start))
